From ef6969eba7756cd971aefb2cbeec4e897a794e92 Mon Sep 17 00:00:00 2001
From: tbrehm <t.brehm@ispconfig.org>
Date: Sun, 18 Oct 2009 13:23:17 -0400
Subject: [PATCH] Added missing newline at the end of apache_ispconfig.conf.master
---
interface/web/mail/mail_transport_edit.php | 59 ++++++++++++++++++++++++++++++++++++++---------------------
1 files changed, 38 insertions(+), 21 deletions(-)
diff --git a/interface/web/mail/mail_transport_edit.php b/interface/web/mail/mail_transport_edit.php
index 6ee7f05..58b06dc 100644
--- a/interface/web/mail/mail_transport_edit.php
+++ b/interface/web/mail/mail_transport_edit.php
@@ -41,11 +41,8 @@
require_once('../../lib/config.inc.php');
require_once('../../lib/app.inc.php');
-// Checking module permissions
-if(!stristr($_SESSION["s"]["user"]["modules"],'mail')) {
- header("Location: ../index.php");
- exit;
-}
+//* Check permissions for module
+$app->auth->check_module_permissions('mail');
// Loading classes
@@ -59,17 +56,11 @@
// we will check only users, not admins
if($_SESSION["s"]["user"]["typ"] == 'user') {
-
- // Get the limits of the client
- $client_group_id = $_SESSION["s"]["user"]["default_group"];
- $client = $app->db->queryOneRecord("SELECT limit_mailrouting FROM sys_group, client WHERE sys_group.client_id = client.client_id and sys_group.groupid = $client_group_id");
-
- // Check if the user may add another transport.
- if($client["limit_mailrouting"] >= 0) {
- $tmp = $app->db->queryOneRecord("SELECT count(transport_id) as number FROM mail_transport WHERE sys_groupid = $client_group_id");
- if($tmp["number"] >= $client["limit_mailrouting"]) {
- $app->error($app->tform->wordbook["limit_mailrouting_txt"]);
- }
+ if(!$app->tform->checkClientLimit('limit_mailrouting')) {
+ $app->error($app->tform->wordbook["limit_mailrouting_txt"]);
+ }
+ if(!$app->tform->checkResellerLimit('limit_mailrouting')) {
+ $app->error('Reseller: '.$app->tform->wordbook["limit_mailrouting_txt"]);
}
}
@@ -85,12 +76,17 @@
} else {
$rec["type"] = $tmp_parts[0];
}
- if(@substr($tmp_parts[1],0,1) == '[') {
+ if(@$tmp_parts[2] != '') {
+ $dest = @$tmp_parts[1].':'.@$tmp_parts[2];
+ } else {
+ $dest = $tmp_parts[1];
+ }
+ if(@substr($dest,0,1) == '[') {
$rec["mx"] = 'checked="CHECKED"';
- $rec["destination"] = @substr($tmp_parts[1],1,-1);
+ $rec["destination"] = @str_replace(']','',@str_replace('[','',$dest));
} else {
$rec["mx"] = '';
- $rec["destination"] = @$tmp_parts[1];
+ $rec["destination"] = @$dest;
}
$types = array('smtp' => 'smtp','uucp' => 'uucp','slow' => 'slow', 'error' => 'error', '' => 'null');
@@ -108,7 +104,23 @@
parent::onShowEnd();
}
-
+
+ function onBeforeUpdate() {
+ global $app, $conf;
+
+ //* Check if the server has been changed
+ // We do this only for the admin or reseller users, as normal clients can not change the server ID anyway
+ if($_SESSION["s"]["user"]["typ"] == 'admin' || $app->auth->has_clients($_SESSION['s']['user']['userid'])) {
+ $rec = $app->db->queryOneRecord("SELECT server_id from mail_transport WHERE transport_id = ".$this->id);
+ if($rec['server_id'] != $this->dataRecord["server_id"]) {
+ //* Add a error message and switch back to old server
+ $app->tform->errorMessage .= $app->lng('The Server can not be changed.');
+ $this->dataRecord["server_id"] = $rec['server_id'];
+ }
+ unset($rec);
+ }
+ }
+
function onSubmit() {
global $app, $conf;
@@ -130,7 +142,12 @@
//* Compose transport field
if($this->dataRecord["mx"] == 'y') {
- $transport = '['.$this->dataRecord["destination"].']';
+ if(stristr($this->dataRecord["destination"],':')) {
+ $tmp_parts = explode(":",$this->dataRecord["destination"]);
+ $transport = '['.$tmp_parts[0].']:'.$tmp_parts[1];
+ } else {
+ $transport = '['.$this->dataRecord["destination"].']';
+ }
} else {
$transport = $this->dataRecord["destination"];
}
--
Gitblit v1.9.1